@@ -1221,6 +1221,33 @@ test_that("docx35: Multiple title blocks work as expected.", {
   
 })
 
+test_that("docx36: Custom page size works as expected.", {
+  
+  fp <- file.path(base_path, "docx/test36.docx")
+  
+  tbl <- create_table(iris[1:15, ]) %>%
+    define(Species, visible = FALSE)
+  
+  ttl <- c("Title1", "Title2", "Title3")
+  
+  rpt <- create_report(fp, output_type = "DOCX", 
+                       font = "Courier",
+                       paper_size = c(6.5, 7.5),
+                       orientation = "portrait") %>%
+    add_content(tbl) %>%
+    page_header("left", "right") %>%
+    page_footer("left", "", "right") %>%
+    titles(ttl,
+           blank_row = "below", columns =  1, align = "center",
+           borders = "none") %>%
+    footnotes("Here is a footnote", "And another")
+  
+  
+  res <- write_report(rpt)
+  
+  expect_equal(file.exists(fp), TRUE)
+  
+})
 
 
 # User Tests --------------------------------------------------------------
