@@ -950,6 +950,34 @@ test_that("html29: Multiple title blocks work as expected.", {
 })
 
 
+test_that("html30: Custom page size works as expected.", {
+  
+  fp <- file.path(base_path, "html/test30.html")
+  
+  tbl <- create_table(iris[1:15, ]) %>%
+    define(Species, visible = FALSE)
+  
+  ttl <- c("Title1", "Title2", "Title3")
+  
+  rpt <- create_report(fp, output_type = "HTML", 
+                       font = "Courier",
+                       paper_size = c(6.5, 7.5),
+                       orientation = "portrait") %>%
+    add_content(tbl) %>%
+    page_header("left", "right") %>%
+    page_footer("left", "", "right") %>%
+    titles(ttl,
+           blank_row = "below", columns =  1, align = "center",
+           borders = "none") %>%
+    footnotes("Here is a footnote", "And another")
+  
+  
+  res <- write_report(rpt)
+  
+  expect_equal(file.exists(fp), TRUE)
+  
+})
+
 
 # User Tests --------------------------------------------------------------
 
