@@ -2841,4 +2841,30 @@ test_that("test86: Titles can be passed as a vector.", {
   
 })
 
+test_that("test87: Custom page size works as expected.", {
+  
+  fp <- file.path(base_path, "output/test87.out")
+  
+  tbl <- create_table(iris[1:15, ]) %>%
+    define(Species, visible = FALSE)
+  
+  ttl <- c("Title1", "Title2", "Title3")
+  
+  rpt <- create_report(fp, output_type = "TXT", paper_size = c(6.5, 7.5),
+                       orientation = "portrait") %>%
+    add_content(tbl) %>%
+    page_header("left", "right") %>%
+    page_footer("left", "", "right") %>%
+    titles(ttl,
+           blank_row = "below", columns =  1, align = "center",
+           borders = "none") %>%
+    footnotes("Here is a footnote", "And another")
+  
+  
+  res <- write_report(rpt)
+  
+  expect_equal(file.exists(fp), TRUE)
+  
+})
+
 
